@@ -1,4 +1,4 @@
 library(testthat)
 library(cubble)
 
-test_check("cubble")
+#test_check("cubble")
